package com.bonus.canteen.core.kitchen.service;

import java.util.List;
import com.bonus.canteen.core.kitchen.domain.KitchenSampleCabinetRecord;

/**
 * 留样柜操作记录Service接口
 * 
 * @author xsheng
 * @date 2025-06-16
 */
public interface IKitchenSampleCabinetRecordService {
    /**
     * 查询留样柜操作记录
     * 
     * @param recordId 留样柜操作记录主键
     * @return 留样柜操作记录
     */
    public KitchenSampleCabinetRecord selectKitchenSampleCabinetRecordByRecordId(Long recordId);

    /**
     * 查询留样柜操作记录列表
     * 
     * @param kitchenSampleCabinetRecord 留样柜操作记录
     * @return 留样柜操作记录集合
     */
    public List<KitchenSampleCabinetRecord> selectKitchenSampleCabinetRecordList(KitchenSampleCabinetRecord kitchenSampleCabinetRecord);

    /**
     * 新增留样柜操作记录
     * 
     * @param kitchenSampleCabinetRecord 留样柜操作记录
     * @return 结果
     */
    public int insertKitchenSampleCabinetRecord(KitchenSampleCabinetRecord kitchenSampleCabinetRecord);

    /**
     * 修改留样柜操作记录
     * 
     * @param kitchenSampleCabinetRecord 留样柜操作记录
     * @return 结果
     */
    public int updateKitchenSampleCabinetRecord(KitchenSampleCabinetRecord kitchenSampleCabinetRecord);

    /**
     * 批量删除留样柜操作记录
     * 
     * @param recordIds 需要删除的留样柜操作记录主键集合
     * @return 结果
     */
    public int deleteKitchenSampleCabinetRecordByRecordIds(Long[] recordIds);

    /**
     * 删除留样柜操作记录信息
     * 
     * @param recordId 留样柜操作记录主键
     * @return 结果
     */
    public int deleteKitchenSampleCabinetRecordByRecordId(Long recordId);
}
