package com.bonus.canteen.core.kitchen.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.kitchen.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.kitchen.domain.KitchenSampleCabinetRecord;
import com.bonus.canteen.core.kitchen.service.IKitchenSampleCabinetRecordService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 留样柜操作记录Controller
 * 
 * @author xsheng
 * @date 2025-06-16
 */
@Api(tags = "留样柜操作记录接口")
@RestController
@RequestMapping("/kitchen_sample_cabinet_record")
public class KitchenSampleCabinetRecordController extends BaseController {
    @Autowired
    private IKitchenSampleCabinetRecordService kitchenSampleCabinetRecordService;

    /**
     * 查询留样柜操作记录列表
     */
    @ApiOperation(value = "查询留样柜操作记录列表")
    //@RequiresPermissions("kitchen:record:list")
    @PostMapping("/list")
    public TableDataInfo list(@RequestBody @Valid KitchenSampleCabinetRecord kitchenSampleCabinetRecord) {
        startPage();
        List<KitchenSampleCabinetRecord> list = kitchenSampleCabinetRecordService.selectKitchenSampleCabinetRecordList(kitchenSampleCabinetRecord);
        return getDataTable(list);
    }

    /**
     * 导出留样柜操作记录列表
     */
    @ApiOperation(value = "导出留样柜操作记录列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:record:export")
    @SysLog(title = "留样柜操作记录", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出留样柜操作记录")
    @PostMapping("/export")
    public void export(HttpServletResponse response, KitchenSampleCabinetRecord kitchenSampleCabinetRecord) {
        List<KitchenSampleCabinetRecord> list = kitchenSampleCabinetRecordService.selectKitchenSampleCabinetRecordList(kitchenSampleCabinetRecord);
        ExcelUtil<KitchenSampleCabinetRecord> util = new ExcelUtil<KitchenSampleCabinetRecord>(KitchenSampleCabinetRecord.class);
        util.exportExcel(response, list, "留样柜操作记录数据");
    }

    /**
     * 获取留样柜操作记录详细信息
     */
    @ApiOperation(value = "获取留样柜操作记录详细信息")
    //@RequiresPermissions("kitchen:record:query")
    @GetMapping(value = "/{recordId}")
    public AjaxResult getInfo(@PathVariable("recordId") Long recordId) {
        return success(kitchenSampleCabinetRecordService.selectKitchenSampleCabinetRecordByRecordId(recordId));
    }

    /**
     * 新增留样柜操作记录
     */
    @ApiOperation(value = "新增留样柜操作记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:record:add")
    @SysLog(title = "留样柜操作记录", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增留样柜操作记录")
    @PostMapping
    public AjaxResult add(@RequestBody KitchenSampleCabinetRecord kitchenSampleCabinetRecord) {
        try {
            return toAjax(kitchenSampleCabinetRecordService.insertKitchenSampleCabinetRecord(kitchenSampleCabinetRecord));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改留样柜操作记录
     */
    @ApiOperation(value = "修改留样柜操作记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:record:edit")
    @SysLog(title = "留样柜操作记录", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改留样柜操作记录")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody KitchenSampleCabinetRecord kitchenSampleCabinetRecord) {
        try {
            return toAjax(kitchenSampleCabinetRecordService.updateKitchenSampleCabinetRecord(kitchenSampleCabinetRecord));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除留样柜操作记录
     */
    @ApiOperation(value = "删除留样柜操作记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:record:remove")
    @SysLog(title = "留样柜操作记录", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除留样柜操作记录")
	@PostMapping("/del/{recordIds}")
    public AjaxResult remove(@PathVariable Long[] recordIds) {
        return toAjax(kitchenSampleCabinetRecordService.deleteKitchenSampleCabinetRecordByRecordIds(recordIds));
    }
}
